@@ -1,8 +1,9 @@
 import numpy as np
-import ocelot.adaptors.astra2ocelot as oca
 import torch
 from torch.distributions import MultivariateNormal
 
+from cheetah.utils import from_astrabeam
+
 
 class Beam:
 
@@ -68,8 +69,7 @@ class Beam:
     @classmethod
     def from_astra(cls, path, **kwargs):
         """Load an Astra particle distribution as a Cheetah Beam."""
-        ocelot_parray = oca.astraBeam2particleArray(path, print_params=False)
-        return cls.from_ocelot(ocelot_parray, **kwargs)
+        raise NotImplementedError
 
     def transformed_to(
         self,
@@ -278,8 +278,14 @@ class ParameterBeam(Beam):
     @classmethod
     def from_astra(cls, path, **kwargs):
         """Load an Astra particle distribution as a Cheetah Beam."""
-        ocelot_parray = oca.astraBeam2particleArray(path, print_params=False)
-        return cls.from_ocelot(ocelot_parray, **kwargs)
+        particles, energy = from_astrabeam(path)
+        mu = torch.ones(7)
+        mu[:6] = torch.tensor(particles.mean(axis=0), dtype=torch.float32)
+
+        cov = torch.zeros(7, 7)
+        cov[:6, :6] = torch.tensor(np.cov(particles.transpose()), dtype=torch.float32)
+
+        return cls(mu=mu, cov=cov, energy=energy)
 
     def transformed_to(
         self,
@@ -596,8 +602,10 @@ class ParticleBeam:
     @classmethod
     def from_astra(cls, path, **kwargs):
         """Load an Astra particle distribution as a Cheetah Beam."""
-        ocelot_parray = oca.astraBeam2particleArray(path, print_params=False)
-        return cls.from_ocelot(ocelot_parray, **kwargs)
+        particles, energy = from_astrabeam(path)
+        particles_7d = torch.ones((particles.shape[0], 7))
+        particles_7d[:, :6] = torch.from_numpy(particles)
+        return cls(particles_7d, energy, **kwargs)
 
     def transformed_to(
         self,
